Module gl

Module gl 

Modules

ffi

Structs

Buffer
ClearMask
Framebuffer
Program
Shader
Texture
UniformLocation
VertexArray

Enums

BufferUsage
Capability
DepthFunction
DrawMode
FramebufferAttachment
ShaderType
TextureSizedInternalFormat
TextureTarget
VertexAttribDataType

Functions

attach_shader
bind_vertex_array
clear
clear_color
compile_shader
create_framebuffer
create_named_buffer
create_named_vertex_array
create_program
create_shader
create_texture
delete_buffer
delete_framebuffer
delete_program
delete_shader
delete_texture
delete_vertex_array
depth_function
Sets the depth function used for depth buffer comparisons. The initial value is DepthFunction::Less.
depth_mask
Enables or disables writing to the depth buffer.
depth_test
Enables or disables depth testing.
disable
Disables a GL capability.
draw_arrays
enable
Enables a GL capability.
enable_vertex_array_attrib
get_program_info_log
get_program_link_status
get_shader_compile_status
get_shader_info_log
get_uniform_location
link_program
named_buffer_data_size
creates and initializes a buffer object’s data store.
named_buffer_data_u8_slice
creates and initializes a buffer object’s data store.
named_framebuffer_texture
program_uniform_1_f32
program_uniform_1_mat4
Specify the value of a uniform variable for a specified program object This function takes a single 4x4 matrix.
shader_source
texture_storage_2d
use_program
vertex_array_attrib_binding
vertex_array_attrib_format
vertex_array_element_buffer
vertex_array_vertex_buffer
viewport