BufferUsage

Enum BufferUsage 

#[repr(u32)]
pub enum BufferUsage { StreamDraw = 35_040, StreamRead = 35_041, StreamCopy = 35_042, StaticDraw = 35_044, StaticRead = 35_045, StaticCopy = 35_046, DynamicDraw = 35_048, DynamicRead = 35_049, DynamicCopy = 35_050, }

Variants



StreamDraw = 35_040

The data store contents will be modified once and used at most a few times. The data store contents are modified by the application, and used as the source for GL drawing and image specification commands.



StreamRead = 35_041

The data store contents will be modified once and used at most a few times. The data store contents are modified by reading data from the GL, and used to return that data when queried by the application.



StreamCopy = 35_042

The data store contents will be modified once and used at most a few times. The data store contents are modified by reading data from the GL, and used as the source for GL drawing and image specification commands.



StaticDraw = 35_044

The data store contents will be modified once and used many times. The data store contents are modified by the application, and used as the source for GL drawing and image specification commands.



StaticRead = 35_045

The data store contents will be modified once and used many times. The data store contents are modified by reading data from the GL, and used to return that data when queried by the application.



StaticCopy = 35_046

The data store contents will be modified once and used many times. The data store contents are modified by reading data from the GL, and used as the source for GL drawing and image specification commands.



DynamicDraw = 35_048

The data store contents will be modified repeatedly and used many times. The data store contents are modified by the application, and used as the source for GL drawing and image specification commands.



DynamicRead = 35_049

The data store contents will be modified repeatedly and used many times. The data store contents are modified by reading data from the GL, and used to return that data when queried by the application.



DynamicCopy = 35_050

The data store contents will be modified repeatedly and used many times. The data store contents are modified by reading data from the GL, and used as the source for GL drawing and image specification commands.