pub unsafe fn depth_function(func: DepthFunction)Expand description
Sets the depth function used for depth buffer comparisons.
The initial value is DepthFunction::Less.
Notes
See OpenGL documentation.
Wraps ffi::glDepthFunc.
pub unsafe fn depth_function(func: DepthFunction)Sets the depth function used for depth buffer comparisons.
The initial value is DepthFunction::Less.
See OpenGL documentation.
Wraps ffi::glDepthFunc.