program_uniform_1_mat4

Function program_uniform_1_mat4 

pub unsafe fn program_uniform_1_mat4(
    program: Program,
    location: UniformLocation,
    transpose: bool,
    value: &[f32],
)
Specify the value of a uniform variable for a specified program object This function takes a single 4x4 matrix.

Parameters

  • program: The program object to which the uniform variable belongs.
  • location: The location of the uniform variable.
  • transpose: Specifies whether to transpose the matrix.
  • value: The matrix value.

Notes

Wraps ffi::glProgramUniformMatrix4fv.