Module ffi

Module ffi 

Constants

ERROR_INVALID_PROFILE_ARB
ERROR_INVALID_VERSION_ARB
WGL_ACCELERATION_ARB
Indicates whether the pixel format is supported by the driver. If this is set to WGL_NO_ACCELERATION_ARB then only the software renderer supports this pixel format; if this is set to WGL_GENERIC_ACCELERATION_ARB then the pixel format is supported by an MCD driver; if this is set to WGL_FULL_ACCELERATION_ARB then the pixel format is supported by an ICD driver.
WGL_ALPHA_BITS_ARB
WGL_COLOR_BITS_ARB
The number of color bitplanes in each color buffer. For RGBA pixel types, it is the size of the color buffer, excluding the alpha bitplanes. For color-index pixels, it is the size of the color index buffer.
WGL_CONTEXT_COMPATIBILITY_PROFILE_BIT_ARB
WGL_CONTEXT_CORE_PROFILE_BIT_ARB
WGL_CONTEXT_DEBUG_BIT_ARB
WGL_CONTEXT_FLAGS_ARB
WGL_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB
WGL_CONTEXT_LAYER_PLANE_ARB
WGL_CONTEXT_MAJOR_VERSION_ARB
WGL_CONTEXT_MINOR_VERSION_ARB
WGL_CONTEXT_PROFILE_MASK_ARB
WGL_DEPTH_BITS_ARB
WGL_DOUBLE_BUFFER_ARB
True if the color buffer has back/front pairs.
WGL_DRAW_TO_WINDOW_ARB
True if the pixel format can be used with a window. The parameter is ignored if this attribute is specified.
WGL_FULL_ACCELERATION_ARB
WGL_GENERIC_ACCELERATION_ARB
WGL_NO_ACCELERATION_ARB
WGL_PIXEL_TYPE_ARB
The type of pixel data. This can be set to WGL_TYPE_RGBA_ARB or WGL_TYPE_COLORINDEX_ARB.
WGL_SAMPLES_ARB
WGL_SAMPLE_BUFFERS_ARB
WGL_STENCIL_BITS_ARB
WGL_SUPPORT_OPENGL_ARB
True if OpenGL is supported.
WGL_TYPE_RGBA_ARB

Functions

load
wglChoosePixelFormatARB
wglCreateContextAttribsARB
wglSwapIntervalEXT

Type Aliases

GLbitfield
GLboolean
GLchar
GLenum
GLfloat
GLint
GLintptr
GLsizei
GLsizeiptr
GLuint