Module wgl

Module wgl 

Modules

ffi

Structs

ContextFlags
ProfileMask

Enums

Acceleration
Represents the acceleration level of the graphics hardware. You almost certainly want to use Acceleration::Full.
ContextAttribute
Various attributes that can be used in creating a context.
IntegerBool
A boolean value that can be used in integer attributes.
PixelFormatAttribute
Various attributes that can be used in choosing a pixel format.
PixelType

Functions

choose_pixel_format
Chooses a pixel format with the given attributes. See https://raw.githubusercontent.com/KhronosGroup/OpenGL-Registry/refs/heads/main/extensions/ARB/WGL_ARB_pixel_format.txt
create_context_attributes
Create a new OpenGL context with the given attributes. See https://raw.githubusercontent.com/KhronosGroup/OpenGL-Registry/refs/heads/main/extensions/ARB/WGL_ARB_create_context.txt
swap_interval
Set the swap interval. See https://raw.githubusercontent.com/KhronosGroup/OpenGL-Registry/refs/heads/main/extensions/EXT/WGL_EXT_swap_control.txt

Type Aliases

HDC
HGLRC