Modules
Structs
Enums
- Acceleration
- Represents the acceleration level of the graphics hardware.
You almost certainly want to use
Acceleration::Full. - Context
Attribute - Various attributes that can be used in creating a context.
- Integer
Bool - A boolean value that can be used in integer attributes.
- Pixel
Format Attribute - Various attributes that can be used in choosing a pixel format.
- Pixel
Type
Functions
- choose_
pixel_ ⚠format - Chooses a pixel format with the given attributes. See https://raw.githubusercontent.com/KhronosGroup/OpenGL-Registry/refs/heads/main/extensions/ARB/WGL_ARB_pixel_format.txt
- create_
context_ ⚠attributes - Create a new OpenGL context with the given attributes. See https://raw.githubusercontent.com/KhronosGroup/OpenGL-Registry/refs/heads/main/extensions/ARB/WGL_ARB_create_context.txt
- swap_
interval ⚠ - Set the swap interval. See https://raw.githubusercontent.com/KhronosGroup/OpenGL-Registry/refs/heads/main/extensions/EXT/WGL_EXT_swap_control.txt