Constants
- ERROR_
INVALID_ PROFILE_ ARB - ERROR_
INVALID_ VERSION_ ARB - WGL_
ACCELERATION_ ARB - Indicates whether the pixel format is supported by the driver. If this is set to WGL_NO_ACCELERATION_ARB then only the software renderer supports this pixel format; if this is set to WGL_GENERIC_ACCELERATION_ARB then the pixel format is supported by an MCD driver; if this is set to WGL_FULL_ACCELERATION_ARB then the pixel format is supported by an ICD driver.
- WGL_
ALPHA_ BITS_ ARB - WGL_
COLOR_ BITS_ ARB - The number of color bitplanes in each color buffer. For RGBA pixel types, it is the size of the color buffer, excluding the alpha bitplanes. For color-index pixels, it is the size of the color index buffer.
- WGL_
CONTEXT_ COMPATIBILITY_ PROFILE_ BIT_ ARB - WGL_
CONTEXT_ CORE_ PROFILE_ BIT_ ARB - WGL_
CONTEXT_ DEBUG_ BIT_ ARB - WGL_
CONTEXT_ FLAGS_ ARB - WGL_
CONTEXT_ FORWARD_ COMPATIBLE_ BIT_ ARB - WGL_
CONTEXT_ LAYER_ PLANE_ ARB - WGL_
CONTEXT_ MAJOR_ VERSION_ ARB - WGL_
CONTEXT_ MINOR_ VERSION_ ARB - WGL_
CONTEXT_ PROFILE_ MASK_ ARB - WGL_
DEPTH_ BITS_ ARB - WGL_
DOUBLE_ BUFFER_ ARB - True if the color buffer has back/front pairs.
- WGL_
DRAW_ TO_ WINDOW_ ARB - True if the pixel format can be used with a window. The
parameter is ignored if this attribute is specified. - WGL_
FULL_ ACCELERATION_ ARB - WGL_
GENERIC_ ACCELERATION_ ARB - WGL_
NO_ ACCELERATION_ ARB - WGL_
PIXEL_ TYPE_ ARB - The type of pixel data. This can be set to WGL_TYPE_RGBA_ARB or WGL_TYPE_COLORINDEX_ARB.
- WGL_
SAMPLES_ ARB - WGL_
SAMPLE_ BUFFERS_ ARB - WGL_
STENCIL_ BITS_ ARB - WGL_
SUPPORT_ OPENGL_ ARB - True if OpenGL is supported.
- WGL_
TYPE_ RGBA_ ARB